@@ -26,8 +26,12 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 #if defined(__WIN32__) || defined(_WIN32)
 #include <strstrea.h>
 #else
+#if defined(__GNUC__) && (__GNUC__ > 3 || __GNUC__ == 3 && __GNUC_MINOR__ > 0)
+#include <strstream>
+#else
 #include <strstream.h>
 #endif
+#endif
 #include <stdio.h>
 
 ///////// OutputSocket //////////
