@@ -147,6 +147,10 @@ int setupStreamSocket(UsageEnvironment& env,
     return -1;
   }
   
+  // SO_REUSEPORT doesn't really make sense for TCP sockets, so we
+  // normally don't set them.  However, if you really want to do this
+  // #define REUSE_FOR_TCP
+#ifdef REUSE_FOR_TCP
 #if defined(__WIN32__) || defined(_WIN32)
     // Windoze doesn't handle SO_REUSEPORT
 #else
@@ -158,6 +162,7 @@ int setupStreamSocket(UsageEnvironment& env,
     return -1;
   }
 #endif
+#endif
 #endif
 
   // Note: Windoze requires binding, even if the port number is 0
@@ -321,7 +326,7 @@ Boolean writeSocket(UsageEnvironment& env,
 
 unsigned increaseBufferTo(UsageEnvironment& env, int bufOptName,
 			  int socket, unsigned requestedSize) {
-	// First, get the current buffer size.  If it's already at leas
+	// First, get the current buffer size.  If it's already at least
 	// as big as what we're requesting, do nothing.
 	unsigned curSize;
 	SOCKLEN_T sizeSize = sizeof curSize;
@@ -439,15 +444,32 @@ Boolean socketLeaveGroupSSM(UsageEnvironment& /*env*/, int socket,
   return True;
 }
 
-Boolean getSourcePort(UsageEnvironment& env, int socket, Port& port) {
-  sockaddr_in test;
+static Boolean getSourcePort0(int socket, portNumBits& resultPortNum/*host order*/) {
+  sockaddr_in test; test.sin_port = 0;
   SOCKLEN_T len = sizeof test;
-  if (getsockname(socket, (struct sockaddr*)&test, &len) < 0) {
-    socketErr(env, "getsockname() error: ");
-    return False;
+  if (getsockname(socket, (struct sockaddr*)&test, &len) < 0) return False;
+  
+  resultPortNum = ntohs(test.sin_port);
+  return True;
+}
+
+Boolean getSourcePort(UsageEnvironment& env, int socket, Port& port) {
+  portNumBits portNum = 0;
+  if (!getSourcePort0(socket, portNum) || portNum == 0) {
+    // Hack - call bind(), then try again:
+    struct sockaddr_in name;
+    name.sin_family = AF_INET;
+    name.sin_port = 0;
+    name.sin_addr.s_addr = INADDR_ANY;
+    bind(socket, (struct sockaddr*)&name, sizeof name);
+
+    if (!getSourcePort0(socket, portNum) || portNum == 0) {
+      socketErr(env, "getsockname() error: ");
+      return False;
+    }
   }
   
-  port = *((Port*)&test.sin_port);
+  port = Port(portNum);
   return True;
 }
 
