@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2003 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2004 Live Networks, Inc.  All rights reserved.
 // File sinks
 // Implementation
 
@@ -112,7 +112,9 @@ Boolean FileSink::continuePlaying() {
 }
 
 void FileSink::afterGettingFrame(void* clientData, unsigned frameSize,
-				 struct timeval presentationTime) {
+				 unsigned /*numTruncatedBytes*/,
+				 struct timeval presentationTime,
+				 unsigned /*durationInMicroseconds*/) {
   FileSink* sink = (FileSink*)clientData;
   sink->afterGettingFrame1(frameSize, presentationTime);
 } 
