@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2002 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2004 Live Networks, Inc.  All rights reserved.
 // Interleaving of MP3 ADUs
 // Implementation
 
@@ -65,10 +65,13 @@ FramedSource* MP3ADUinterleaverBase::getInputSource(UsageEnvironment& env,
 
 void MP3ADUinterleaverBase::afterGettingFrame(void* clientData,
 					      unsigned numBytesRead,
-					      struct timeval presentationTime) {
+					      unsigned /*numTruncatedBytes*/,
+					      struct timeval presentationTime,
+					      unsigned durationInMicroseconds) {
   MP3ADUinterleaverBase* interleaverBase = (MP3ADUinterleaverBase*)clientData;
   // Finish up after reading:
-  interleaverBase->afterGettingFrame(numBytesRead, presentationTime);
+  interleaverBase->afterGettingFrame(numBytesRead,
+				     presentationTime, durationInMicroseconds);
 
   // Then, continue to deliver an outgoing frame:
   interleaverBase->doGetNextFrame();
@@ -89,10 +92,12 @@ public:
   void getReleasingFrameParams(unsigned char index,
 			       unsigned char*& dataPtr,
 			       unsigned& bytesInUse,
-			       struct timeval& presentationTime);
+			       struct timeval& presentationTime,
+			       unsigned& durationInMicroseconds);
   void setFrameParams(unsigned char index,
 		      unsigned char icc, unsigned char ii,
-		      unsigned frameSize, struct timeval presentationTime);
+		      unsigned frameSize, struct timeval presentationTime,
+		      unsigned durationInMicroseconds);
   unsigned nextIndexToRelease() {return fNextIndexToRelease;}
   void releaseNext();
 
@@ -128,7 +133,7 @@ void MP3ADUinterleaver::doGetNextFrame() {
   // If there's a frame immediately available, deliver it, otherwise get new
   // frames from the source until one's available:
   if (fFrames->haveReleaseableFrame()) {
-    fFrameSize = releaseOutgoingFrame(fPresentationTime);
+    releaseOutgoingFrame();
 
     // Call our own 'after getting' function.  Because we're not a 'leaf'
     // source, we can call this directly, without risking infinite recursion.
@@ -147,25 +152,28 @@ void MP3ADUinterleaver::doGetNextFrame() {
   }
 }
 
-unsigned MP3ADUinterleaver::releaseOutgoingFrame(struct timeval& presentationTime) {
+void MP3ADUinterleaver::releaseOutgoingFrame() {
   unsigned char* fromPtr;
-  unsigned bytesToCopy;
   fFrames->getReleasingFrameParams(fFrames->nextIndexToRelease(),
-				   fromPtr, bytesToCopy, presentationTime);
+				   fromPtr, fFrameSize,
+				   fPresentationTime, fDurationInMicroseconds);
 
-  if (fMaxSize < bytesToCopy) bytesToCopy = fMaxSize;
-  memmove(fTo, fromPtr, bytesToCopy);
+  if (fFrameSize > fMaxSize) {
+    fNumTruncatedBytes = fFrameSize - fMaxSize;
+    fFrameSize = fMaxSize;
+  }
+  memmove(fTo, fromPtr, fFrameSize);
 
   fFrames->releaseNext();
-
-  return bytesToCopy;
 }
 
 void MP3ADUinterleaver::afterGettingFrame(unsigned numBytesRead,
-					  struct timeval presentationTime) {
+					  struct timeval presentationTime,
+					  unsigned durationInMicroseconds) {
   // Set the (icc,ii) and frame size of the newly-read frame:
   fFrames->setFrameParams(fPositionOfNextIncomingFrame,
-			  fICC, fII, numBytesRead, presentationTime);
+			  fICC, fII, numBytesRead,
+			  presentationTime, durationInMicroseconds);
 
   // Prepare our counters for the next frame:
   if (++fII == fInterleaving.cycleSize()) {
@@ -186,10 +194,12 @@ public:
 			      unsigned& bytesAvailable);
   void getIncomingFrameParamsAfter(unsigned frameSize,
 				   struct timeval presentationTime,
+				   unsigned durationInMicroseconds,
 				   unsigned char& icc, unsigned char& ii);
   void getReleasingFrameParams(unsigned char*& dataPtr,
 			       unsigned& bytesInUse,
-			       struct timeval& presentationTime);
+			       struct timeval& presentationTime,
+			       unsigned& durationInMicroseconds);
   void moveIncomingFrameIntoPlace();
   void releaseNext();
   void startNewCycle();
@@ -223,7 +233,7 @@ void MP3ADUdeinterleaver::doGetNextFrame() {
   // If there's a frame immediately available, deliver it, otherwise get new
   // frames from the source until one's available:
   if (fFrames->haveReleaseableFrame()) {
-    fFrameSize = releaseOutgoingFrame(fPresentationTime);
+    releaseOutgoingFrame();
 
     // Call our own 'after getting' function.  Because we're not a 'leaf'
     // source, we can call this directly, without risking infinite recursion.
@@ -267,10 +277,12 @@ void MP3ADUdeinterleaver::doGetNextFrame() {
 }
 
 void MP3ADUdeinterleaver::afterGettingFrame(unsigned numBytesRead,
-					    struct timeval presentationTime) {
+					    struct timeval presentationTime,
+					    unsigned durationInMicroseconds) {
   // Get the (icc,ii) and set the frame size of the newly-read frame:
   unsigned char icc, ii;
-  fFrames->getIncomingFrameParamsAfter(numBytesRead, presentationTime,
+  fFrames->getIncomingFrameParamsAfter(numBytesRead,
+				       presentationTime, durationInMicroseconds,
 				       icc, ii);
 
   // Compare these to the values we saw last:
@@ -289,17 +301,18 @@ void MP3ADUdeinterleaver::afterGettingFrame(unsigned numBytesRead,
   fIIlastSeen = ii;
 }
 
-unsigned MP3ADUdeinterleaver::releaseOutgoingFrame(struct timeval& presentationTime) {
+void MP3ADUdeinterleaver::releaseOutgoingFrame() {
   unsigned char* fromPtr;
-  unsigned bytesToCopy;
-  fFrames->getReleasingFrameParams(fromPtr, bytesToCopy, presentationTime);
+  fFrames->getReleasingFrameParams(fromPtr, fFrameSize,
+				   fPresentationTime, fDurationInMicroseconds);
 
-  if (fMaxSize < bytesToCopy) bytesToCopy = fMaxSize;
-  memmove(fTo, fromPtr, bytesToCopy);
+  if (fFrameSize > fMaxSize) {
+    fNumTruncatedBytes = fFrameSize - fMaxSize;
+    fFrameSize = fMaxSize;
+  }
+  memmove(fTo, fromPtr, fFrameSize);
 
   fFrames->releaseNext();
-
-  return bytesToCopy;
 }
 
 ////////// InterleavingFrames (implementation) //////////
@@ -312,6 +325,7 @@ public:
 
   unsigned frameDataSize; // includes ADU descriptor and (modified) MPEG hdr
   struct timeval presentationTime;
+  unsigned durationInMicroseconds;
   unsigned char frameData[MAX_FRAME_SIZE]; // ditto
 };
 
@@ -338,21 +352,25 @@ void InterleavingFrames::getIncomingFrameParams(unsigned char index,
 void InterleavingFrames::getReleasingFrameParams(unsigned char index,
 						 unsigned char*& dataPtr,
 						 unsigned& bytesInUse,
-						 struct timeval& presentationTime) {
+						 struct timeval& presentationTime,
+						 unsigned& durationInMicroseconds) {
   InterleavingFrameDescriptor& desc = fDescriptors[index];
   dataPtr = &desc.frameData[0];
   bytesInUse = desc.frameDataSize;
   presentationTime = desc.presentationTime;
+  durationInMicroseconds = desc.durationInMicroseconds;
 }
 
 void InterleavingFrames::setFrameParams(unsigned char index,
 					unsigned char icc,
 					unsigned char ii,
 					unsigned frameSize,
-					struct timeval presentationTime) {
+					struct timeval presentationTime,
+					unsigned durationInMicroseconds) {
   InterleavingFrameDescriptor& desc = fDescriptors[index];
   desc.frameDataSize = frameSize;
   desc.presentationTime = presentationTime;
+  desc.durationInMicroseconds = durationInMicroseconds;
 
   // Advance over the ADU descriptor, to get to the MPEG 'syncword':
   unsigned char* ptr = &desc.frameData[0];
@@ -378,6 +396,7 @@ public:
 
   unsigned frameDataSize; // includes ADU descriptor and (modified) MPEG hdr
   struct timeval presentationTime;
+  unsigned durationInMicroseconds;
   unsigned char* frameData;
 };
 
@@ -437,13 +456,15 @@ void DeinterleavingFrames::getIncomingFrameParams(unsigned char*& dataPtr,
   bytesAvailable = MAX_FRAME_SIZE;
 }
 
-void DeinterleavingFrames::getIncomingFrameParamsAfter(unsigned frameSize,
-						       struct timeval presentationTime,
-						       unsigned char& icc,
-						       unsigned char& ii) {
+void DeinterleavingFrames
+::getIncomingFrameParamsAfter(unsigned frameSize,
+			      struct timeval presentationTime,
+			      unsigned durationInMicroseconds,
+			      unsigned char& icc, unsigned char& ii) {
   DeinterleavingFrameDescriptor& desc = fDescriptors[MAX_CYCLE_SIZE];
   desc.frameDataSize = frameSize;
   desc.presentationTime = presentationTime;
+  desc.durationInMicroseconds = durationInMicroseconds;
   
   // Advance over the ADU descriptor, to get to the MPEG 'syncword':
   unsigned char* ptr = desc.frameData;
@@ -456,11 +477,13 @@ void DeinterleavingFrames::getIncomingFrameParamsAfter(unsigned frameSize,
 
 void DeinterleavingFrames::getReleasingFrameParams(unsigned char*& dataPtr,
 						   unsigned& bytesInUse,
-						   struct timeval& presentationTime) {
+						   struct timeval& presentationTime,
+						   unsigned& durationInMicroseconds) {
   DeinterleavingFrameDescriptor& desc = fDescriptors[fNextIndexToRelease];
   dataPtr = desc.frameData;
   bytesInUse = desc.frameDataSize;
   presentationTime = desc.presentationTime;
+  durationInMicroseconds = desc.durationInMicroseconds;
 }
 
 void DeinterleavingFrames::moveIncomingFrameIntoPlace() {
