@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2002 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2004 Live Networks, Inc.  All rights reserved.
 // Demultiplexer for a MPEG 1 or 2 Program Stream
 // Implementation
 
@@ -61,10 +61,12 @@ private:
 
 ////////// MPEG1or2Demux implementation //////////
 
-MPEG1or2Demux::MPEG1or2Demux(UsageEnvironment& env,
-		     FramedSource* inputSource)
+MPEG1or2Demux
+::MPEG1or2Demux(UsageEnvironment& env,
+		FramedSource* inputSource, Boolean reclaimWhenLastESDies)
   : Medium(env), fInputSource(inputSource),
     fNextAudioStreamNumber(0), fNextVideoStreamNumber(0),
+    fReclaimWhenLastESDies(reclaimWhenLastESDies), fNumOutstandingESs(0),
     fNumPendingReads(0), fHaveUndeliveredData(False) {
   fParser = new MPEGProgramStreamParser(this, inputSource);
   for (unsigned i = 0; i < 256; ++i) {
@@ -78,15 +80,24 @@ MPEG1or2Demux::~MPEG1or2Demux() {
   Medium::close(fInputSource);
 }
 
-MPEG1or2Demux* MPEG1or2Demux::createNew(UsageEnvironment& env,
-				FramedSource* inputSource) {
+MPEG1or2Demux* MPEG1or2Demux
+::createNew(UsageEnvironment& env,
+	    FramedSource* inputSource, Boolean reclaimWhenLastESDies) {
   // Need to add source type checking here???  #####
 
-  return new MPEG1or2Demux(env, inputSource);
+  return new MPEG1or2Demux(env, inputSource, reclaimWhenLastESDies);
+}
+
+void MPEG1or2Demux
+::noteElementaryStreamDeletion(MPEG1or2DemuxedElementaryStream* /*es*/) {
+  if (--fNumOutstandingESs == 0 && fReclaimWhenLastESDies) {
+    delete this;
+  }
 }
 
 MPEG1or2DemuxedElementaryStream*
-MPEG1or2Demux::newElementaryStream(unsigned char streamIdTag) {
+MPEG1or2Demux::newElementaryStream(u_int8_t streamIdTag) {
+  ++fNumOutstandingESs;
   return new MPEG1or2DemuxedElementaryStream(envir(), streamIdTag, *this);
 }
 
@@ -102,11 +113,11 @@ MPEG1or2DemuxedElementaryStream* MPEG1or2Demux::newVideoStream() {
   return newElementaryStream(newVideoStreamTag);
 }
 
-void MPEG1or2Demux::registerReadInterest(unsigned char streamIdTag,
+void MPEG1or2Demux::registerReadInterest(u_int8_t streamIdTag,
 				     unsigned char* to, unsigned maxSize,
-				     afterGettingFunc* afterGettingFunc,
+				     FramedSource::afterGettingFunc* afterGettingFunc,
 				     void* afterGettingClientData,
-				     onCloseFunc* onCloseFunc,
+				     FramedSource::onCloseFunc* onCloseFunc,
 				     void* onCloseClientData) {
   struct OutputDescriptor& out = fOutput[streamIdTag];
     
@@ -152,7 +163,9 @@ void MPEG1or2Demux::continueReadProcessing() {
       // source, we can call this directly, without risking infinite recursion.
       if (newOut.fAfterGettingFunc != NULL) {
 	(*newOut.fAfterGettingFunc)(newOut.afterGettingClientData,
-				    newOut.frameSize, newOut.presentationTime);
+				    newOut.frameSize, 0 /* numTruncatedBytes */,
+				    newOut.presentationTime,
+				    0 /* durationInMicroseconds ?????#####*/);
       --fNumPendingReads;
       }
     } else {
@@ -166,11 +179,11 @@ void MPEG1or2Demux::continueReadProcessing() {
   }
 }
 
-void MPEG1or2Demux::getNextFrame(unsigned char streamIdTag,
+void MPEG1or2Demux::getNextFrame(u_int8_t streamIdTag,
 			     unsigned char* to, unsigned maxSize,
-			     afterGettingFunc* afterGettingFunc,
+			     FramedSource::afterGettingFunc* afterGettingFunc,
 			     void* afterGettingClientData,
-			     onCloseFunc* onCloseFunc,
+			     FramedSource::onCloseFunc* onCloseFunc,
 			     void* onCloseClientData) {
   // Begin by saving the parameters of the specified stream id:
   registerReadInterest(streamIdTag, to, maxSize,
@@ -184,7 +197,7 @@ void MPEG1or2Demux::getNextFrame(unsigned char streamIdTag,
   } // otherwise the continued read processing has already been taken care of
 }
 
-void MPEG1or2Demux::stopGettingFrames(unsigned char streamIdTag) {
+void MPEG1or2Demux::stopGettingFrames(u_int8_t streamIdTag) {
     struct OutputDescriptor& out = fOutput[streamIdTag];
     out.isCurrentlyActive = out.isCurrentlyAwaitingData = False;
 }
@@ -199,7 +212,7 @@ void MPEG1or2Demux::handleClosure(void* clientData) {
   // (etc.) before we start calling any of them, in case one of them
   // ends up deleting this.
   struct {
-    onCloseFunc* fOnCloseFunc;
+    FramedSource::onCloseFunc* fOnCloseFunc;
     void* onCloseClientData;
   } savedPending[256];
   unsigned i, numPending = 0;
@@ -262,7 +275,7 @@ unsigned char MPEGProgramStreamParser::parse() {
     return acquiredStreamTagId;
   } catch (int /*e*/) {
 #ifdef DEBUG
-    fprintf(stderr, "MPEGProgramStreamParser::parse() EXCEPTION\n");
+    fprintf(stderr, "MPEGProgramStreamParser::parse() EXCEPTION (This is normal behavior - *not* an error)\n");
     fflush(stderr);
 #endif
     return 0;  // the parsing got interrupted
