@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2002 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2004 Live Networks, Inc.  All rights reserved.
 // A MPEG 1 or 2 Elementary Stream, demultiplexed from a Program Stream
 // Implementation
 
@@ -23,7 +23,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 ////////// MPEG1or2DemuxedElementaryStream //////////
 
 MPEG1or2DemuxedElementaryStream::
-MPEG1or2DemuxedElementaryStream(UsageEnvironment& env, unsigned char streamIdTag,
+MPEG1or2DemuxedElementaryStream(UsageEnvironment& env, u_int8_t streamIdTag,
 			    MPEG1or2Demux& sourceDemux)
   : FramedSource(env),
     fOurStreamIdTag(streamIdTag), fOurSourceDemux(sourceDemux) {
@@ -38,6 +38,7 @@ MPEG1or2DemuxedElementaryStream(UsageEnvironment& env, unsigned char streamIdTag
 }
 
 MPEG1or2DemuxedElementaryStream::~MPEG1or2DemuxedElementaryStream() {
+  fOurSourceDemux.noteElementaryStreamDeletion(this);
 }
 
 void MPEG1or2DemuxedElementaryStream::doGetNextFrame() {
@@ -55,21 +56,21 @@ char const* MPEG1or2DemuxedElementaryStream::MIMEtype() const {
 }
 
 unsigned MPEG1or2DemuxedElementaryStream::maxFrameSize() const {
-  return 10000;
+  return 25000;
   // This is a hack, which might break for some MPEG sources, because
   // the MPEG spec allows for PES packets as large as ~65536 bytes. #####
 }
 
-float MPEG1or2DemuxedElementaryStream::getPlayTime(unsigned numFrames) const {
-  return fOurSourceDemux.inputSource()->getPlayTime(numFrames);
-}
-
 void MPEG1or2DemuxedElementaryStream
 ::afterGettingFrame(void* clientData,
-		    unsigned frameSize, struct timeval presentationTime) {
+		    unsigned frameSize, unsigned numTruncatedBytes,
+		    struct timeval presentationTime,
+		    unsigned durationInMicroseconds) {
   MPEG1or2DemuxedElementaryStream* stream
     = (MPEG1or2DemuxedElementaryStream*)clientData;
   stream->fFrameSize = frameSize;
+  stream->fNumTruncatedBytes = numTruncatedBytes;
   stream->fPresentationTime = presentationTime;
+  stream->fDurationInMicroseconds = durationInMicroseconds;
   FramedSource::afterGetting(stream);
 }
