@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2003 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2004 Live Networks, Inc.  All rights reserved.
 // A filter that breaks up an MPEG video elementary stream into
 //   headers and frames
 // Implementation
@@ -36,7 +36,6 @@ int TimeCode::operator==(TimeCode const& arg2) {
     && minutes == arg2.minutes && hours == arg2.hours && days == arg2.days;
 }
 
-
 ////////// MPEGVideoStreamFramer implementation //////////
 
 #ifdef BSD
@@ -60,6 +59,9 @@ MPEGVideoStreamFramer::~MPEGVideoStreamFramer() {
   delete fParser;
 }
 
+#ifdef DEBUG
+static struct timeval firstPT;
+#endif
 void MPEGVideoStreamFramer
 ::computePresentationTime(unsigned numAdditionalPictures) {
   // Computes "fPresentationTime" from the most recent GOP's
@@ -81,8 +83,16 @@ void MPEGVideoStreamFramer
     fPresentationTime.tv_usec -= 1000000;
     ++fPresentationTime.tv_sec;
   }
-#ifdef DEBUG_COMPUTE_PRESENTATION_TIME
-  fprintf(stderr, "MPEGVideoStreamFramer::computePresentationTime(%d) -> %u.%06d\n", numAdditionalPictures, fPresentationTime.tv_sec, fPresentationTime.tv_usec);
+#ifdef DEBUG
+  if (firstPT.tv_sec == 0 && firstPT.tv_usec == 0) firstPT = fPresentationTime;
+  struct timeval diffPT;
+  diffPT.tv_sec = fPresentationTime.tv_sec - firstPT.tv_sec; 
+  diffPT.tv_usec = fPresentationTime.tv_usec - firstPT.tv_usec; 
+  if (fPresentationTime.tv_usec < firstPT.tv_usec) {
+    --diffPT.tv_sec;
+    diffPT.tv_usec += 1000000;
+  }
+  fprintf(stderr, "MPEGVideoStreamFramer::computePresentationTime(%d) -> %lu.%06ld [%lu.%06ld]\n", numAdditionalPictures, fPresentationTime.tv_sec, fPresentationTime.tv_usec, diffPT.tv_sec, diffPT.tv_usec);
 #endif
 }
 
@@ -119,17 +129,6 @@ void MPEGVideoStreamFramer::doGetNextFrame() {
   continueReadProcessing();
 }
 
-float MPEGVideoStreamFramer::getPlayTime(unsigned /*numFrames*/) const {
-  // OK, this is going to be a bit of a hack, because the actual play time
-  // for us is going to be based not on "numFrames", but instead on how
-  // many *pictures* have been completed since the last call to this
-  // function.  (I.e., it's a hack because we're making an assumption about
-  // *why* this member function is being called.)
-  double result = fFrameRate == 0.0 ? 0.0 : fPictureCount/fFrameRate;
-  ((MPEGVideoStreamFramer*)this)->fPictureCount = 0; // told you it's a hack
-  return (float)result;
-}
-
 void MPEGVideoStreamFramer::continueReadProcessing(void* clientData,
 						   unsigned char* /*ptr*/,
 						   unsigned /*size*/) {
@@ -144,6 +143,16 @@ void MPEGVideoStreamFramer::continueReadProcessing() {
     // It has already been copied to the reader's space.
     fFrameSize = acquiredFrameSize;
     
+    // "fPresentationTime" should have already been computed.
+    // Compute "fDurationInMicroseconds" now:
+    fDurationInMicroseconds
+      = (fFrameRate == 0.0 || ((int)fPictureCount) < 0) ? 0
+      : (unsigned)((fPictureCount*1000000)/fFrameRate);
+#ifdef DEBUG
+    fprintf(stderr, "fDurationInMicroseconds: %d ((%d*1000000)/%f)\n", fDurationInMicroseconds, fPictureCount, fFrameRate);
+#endif
+    fPictureCount = 0;
+
     // Call our own 'after getting' function.  Because we're not a 'leaf'
     // source, we can call this directly, without risking infinite recursion.
     afterGetting(this);
@@ -153,4 +162,3 @@ void MPEGVideoStreamFramer::continueReadProcessing() {
     // - the source stream has ended.
   }
 }
-
