@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2002 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2004 Live Networks, Inc.  All rights reserved.
 // A generic RTSP client
 // Implementation
 
@@ -24,7 +24,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 #include <stdlib.h>
 
 #if defined(__WIN32__) || defined(_WIN32) || defined(_QNX4)
-#define _strncasecmp strncmp
+#define _strncasecmp _strnicmp
 #else
 #define _strncasecmp strncasecmp
 #endif
@@ -310,7 +310,20 @@ char* RTSPClient::describeURL(char const* url, AuthRecord* authenticator) {
 	if (numExtraBytesNeeded > 0) break; // one of the reads failed
       }
 
-      bodyStart[contentLength] = '\0'; // trims any extra data
+      // Remove any '\0' characters from inside the SDP description.
+      // Any such characters would violate the SDP specification, but
+      // some RTSP servers have been known to include them:
+      int from, to = 0;
+      for (from = 0; from < contentLength; ++from) {
+	if (bodyStart[from] != '\0') {
+	  if (to != from) bodyStart[to] = bodyStart[from];
+	  ++to;
+	}
+      }
+      if (from != to && fVerbosityLevel >= 1) {
+	envir() << "Warning: " << from-to << " invalid 'NULL' bytes were found in (and removed from) the SDP description.\n";
+      }
+      bodyStart[to] = '\0'; // trims any extra data
     }
 
     delete[] cmd;
@@ -406,7 +419,7 @@ char* RTSPClient::sendOptionsCmd(char const* url) {
 
       nextLineStart = getLine(lineStart);
 
-      if (_strncasecmp(lineStart, "public: ", 8) == 0) {
+      if (_strncasecmp(lineStart, "Public: ", 8) == 0) {
 	result = strDup(&lineStart[8]);
 	break;
       }
@@ -434,6 +447,15 @@ void RTSPClient::constructSubsessionURL(MediaSubsession const& subsession,
 					char const*& suffix) {
   // Figure out what the URL describing "subsession" will look like.
   // The URL is returned in three parts: prefix; separator; suffix
+  //##### NOTE: This code doesn't really do the right thing if "fBaseURL"
+  // doesn't end with a "/", and "subsession.controlPath()" is relative.
+  // The right thing would have been to truncate "fBaseURL" back to the
+  // rightmost "/", and then add "subsession.controlPath()".
+  // In practice, though, each "DESCRIBE" response typically contains
+  // a "Content-Base:" header that consists of "fBaseURL" followed by
+  // a "/", in which case this code ends up giving the correct result.
+  // However, we should really fix this code to do the right thing, and
+  // also check for and use the "Content-Base:" header appropriately. #####
   prefix = fBaseURL;
   if (prefix == NULL) prefix = "";
 
@@ -1324,7 +1346,7 @@ Boolean RTSPClient::parseRTSPURL(UsageEnvironment& env, char const* url,
     NetAddressList addresses(parseBuffer);
     if (addresses.numAddresses() == 0) {
       env.setResultMsg("Failed to find network address for \"",
-			   parseBuffer, "\"");
+		       parseBuffer, "\"");
       break;
     }
     address = *(addresses.firstAddress());
@@ -1560,13 +1582,18 @@ Boolean RTSPClient::parseTransportResponse(char const* line,
 					   portNumBits& serverPortNum,
 					   unsigned char& rtpChannelId,
 					   unsigned char& rtcpChannelId) {
+  // Initialize the return parameters to 'not found' values:
+  serverAddressStr = NULL;
+  serverPortNum = 0;
+  rtpChannelId = rtcpChannelId = 0xFF;
+
   char* foundServerAddressStr = NULL;
   Boolean foundServerPortNum = False;
   Boolean foundChannelIds = False;
   unsigned rtpCid, rtcpCid;
 
   // First, check for "Transport:"
-  if (_strncasecmp(line, "transport: ", 11) != 0) return False;
+  if (_strncasecmp(line, "Transport: ", 11) != 0) return False;
   line += 11;
 
   // Then, run through each of the fields, looking for ones we handle:
@@ -1584,19 +1611,15 @@ Boolean RTSPClient::parseTransportResponse(char const* line,
       foundChannelIds = True;
     }
 
-    // (Later, do more extensive checking on the "Transport: " hdr #####)
-
     fields += strlen(field);
+    while (fields[0] == ';') ++fields; // skip over all leading ';' chars
     if (fields[0] == '\0') break;
-    ++fields; // skip over the ';'
   }
   delete[] field;
 
-  if (foundServerPortNum) {
+  if (foundServerPortNum || foundChannelIds) {
     serverAddressStr = foundServerAddressStr;
     return True;
-  } else if (foundChannelIds) {
-    return True;
   }
 
   delete[] foundServerAddressStr;
@@ -1607,7 +1630,7 @@ Boolean RTSPClient::parseRTPInfoHeader(char const* line,
 				       unsigned& trackId,
 				       u_int16_t& seqNum,
 				       u_int32_t& timestamp) {
-  if (_strncasecmp(line, "rtp-info: ", 10) != 0) return False;
+  if (_strncasecmp(line, "RTP-Info: ", 10) != 0) return False;
   line += 10;
   char const* fields = line;
   char* field = strDupSize(fields);
