@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2002 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2004 Live Networks, Inc.  All rights reserved.
 // A generic SIP client
 // Implementation
 
@@ -23,15 +23,11 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 #include "GroupsockHelper.hh"
 #include <stdlib.h>
 
-#if defined(__WIN32__) || defined(_WIN32)
-#define _strncasecmp strncmp
-#else
-#if defined(_QNX4)
-#define _strncasecmp strncmp
+#if defined(__WIN32__) || defined(_WIN32) || defined(_QNX4)
+#define _strncasecmp _strnicmp
 #else
 #define _strncasecmp strncasecmp
 #endif
-#endif
 
 ////////// SIPClient //////////
 
