@@ -131,9 +131,9 @@ void play() {
     exit(1);
   }
   ServerMediaSession* sms
-    = ServerMediaSession::createNew(*env, NULL, "GSM input",
+    = ServerMediaSession::createNew(*env, "testStream", "GSM input",
 		"Session streamed by \"testGSMStreamer\"", isSSM);
-  sms->addSubsession(PassiveServerMediaSubsession::createNew(*sessionState.sink));
+  sms->addSubsession(PassiveServerMediaSubsession::createNew(*sessionState.sink, sessionState.rtcpInstance));
   rtspServer->addServerMediaSession(sms);
 
   char* url = rtspServer->rtspURL(sms);
