@@ -170,9 +170,9 @@ void play() {
     exit(1);
   }
   ServerMediaSession* sms
-    = ServerMediaSession::createNew(*env, NULL, inputFileName,
+    = ServerMediaSession::createNew(*env, "testStream", inputFileName,
 		"Session streamed by \"testMP3Streamer\"", isSSM);
-  sms->addSubsession(PassiveServerMediaSubsession::createNew(*sessionState.sink));
+  sms->addSubsession(PassiveServerMediaSubsession::createNew(*sessionState.sink, sessionState.rtcpInstance));
   rtspServer->addServerMediaSession(sms);
 
   char* url = rtspServer->rtspURL(sms);
