@@ -24,10 +24,6 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 #include "BasicUsageEnvironment.hh"
 #include "GroupsockHelper.hh"
 
-// Use an internal RTSP server:
-#define IMPLEMENT_RTSP_SERVER 1
-// (Note that this RTSP server works for multicast only)
-
 char const* programName;
 // Whether to stream *only* "I" (key) frames
 // (e.g., to reduce network bandwidth):
@@ -46,12 +42,12 @@ MPEG1or2Demux* mpegDemux;
 AC3AudioStreamFramer* audioSource = NULL;
 FramedSource* videoSource = NULL;
 RTPSink* audioSink = NULL;
+RTCPInstance* audioRTCP = NULL;
 RTPSink* videoSink = NULL;
-#ifdef IMPLEMENT_RTSP_SERVER
+RTCPInstance* videoRTCP = NULL;
 RTSPServer* rtspServer = NULL;
 unsigned short const defaultRTSPServerPortNum = 554;
 unsigned short rtspServerPortNum = defaultRTSPServerPortNum;
-#endif
 
 Groupsock* rtpGroupsockAudio;
 Groupsock* rtcpGroupsockAudio;
@@ -60,9 +56,7 @@ Groupsock* rtcpGroupsockVideo;
 
 void usage() {
   *env << "usage: " << programName << " [-i] [-a|-v] "
-#ifdef IMPLEMENT_RTSP_SERVER
 	  "[-p <RTSP-server-port-number>] "
-#endif
 	  "<VOB-file>...<VOB-file>\n";
   exit(1);
 }
@@ -168,10 +162,10 @@ int main(int argc, char const** argv) {
     rtcpGroupsockAudio->multicastSendOnly(); // because we're a SSM source
     const unsigned totalSessionBandwidthAudio
       = 160; // in kbps; for RTCP b/w share
-    RTCPInstance::createNew(*env, rtcpGroupsockAudio,
-			    totalSessionBandwidthAudio, CNAME,
-			    audioSink, NULL /* we're a server */,
-			    True /* we're a SSM source */);
+    audioRTCP = RTCPInstance::createNew(*env, rtcpGroupsockAudio,
+					totalSessionBandwidthAudio, CNAME,
+					audioSink, NULL /* we're a server */,
+					True /* we're a SSM source */);
     // Note: This starts RTCP running automatically
   }
 
@@ -189,14 +183,13 @@ int main(int argc, char const** argv) {
     rtcpGroupsockVideo->multicastSendOnly(); // because we're a SSM source
     const unsigned totalSessionBandwidthVideo
       = 4500; // in kbps; for RTCP b/w share
-    RTCPInstance::createNew(*env, rtcpGroupsockVideo,
-			    totalSessionBandwidthVideo, CNAME,
-			    videoSink, NULL /* we're a server */,
-			    True /* we're a SSM source */);
+    videoRTCP = RTCPInstance::createNew(*env, rtcpGroupsockVideo,
+					totalSessionBandwidthVideo, CNAME,
+					videoSink, NULL /* we're a server */,
+					True /* we're a SSM source */);
     // Note: This starts RTCP running automatically
   }
 
-#ifdef IMPLEMENT_RTSP_SERVER
   if (rtspServer == NULL) {
     rtspServer = RTSPServer::createNew(*env, rtspServerPortNum);
     if (rtspServer == NULL) {
@@ -205,10 +198,10 @@ int main(int argc, char const** argv) {
       exit(1);
     }
     ServerMediaSession* sms
-      = ServerMediaSession::createNew(*env, NULL, *curInputFileName,
+      = ServerMediaSession::createNew(*env, "vobStream", *curInputFileName,
 	     "Session streamed by \"vobStreamer\"", True /*SSM*/);
-    if (audioSink != NULL) sms->addSubsession(PassiveServerMediaSubsession::createNew(*audioSink));
-    if (videoSink != NULL) sms->addSubsession(PassiveServerMediaSubsession::createNew(*videoSink));
+    if (audioSink != NULL) sms->addSubsession(PassiveServerMediaSubsession::createNew(*audioSink, audioRTCP));
+    if (videoSink != NULL) sms->addSubsession(PassiveServerMediaSubsession::createNew(*videoSink, videoRTCP));
     rtspServer->addServerMediaSession(sms);
 
     *env << "Created RTSP server.\n";
@@ -218,7 +211,6 @@ int main(int argc, char const** argv) {
     *env << "Access this stream using the URL:\n\t" << url << "\n";
     delete[] url;
   }
-#endif
 
   // Finally, start the streaming:
   *env << "Beginning streaming...\n";
